# Configuration file for IP Checker

# Link to api. It should not be changed
api = "https://api.greynoise.io/v3/community/"

# Frequency of checking (in seconds). Default is 10 min
checktime = 600

# "Paranoia" level. Specify in what case you should get notification. There are 3 avaiable modes: low, medium and high. Default is medium
paranoia = 'medium'

# Location of log file
log = '/tmp/ipchecker.log'

